@@ -4,6 +4,7 @@ import logging
 
 from flexget import plugin
 from flexget.event import event
+from flexget.plugins.plugin_urlrewriting import UrlRewritingError
 
 log = logging.getLogger('urlrewrite')
 
@@ -22,15 +23,6 @@ class UrlRewrite(object):
 
     resolves = {}
 
-    # built-in resolves
-
-#    resolves = yaml.safe_load("""
-#    tvsubtitles:
-#      match: http://www.tvsubtitles.net/subtitle-
-#      replace: http://www.tvsubtitles.net/download-
-#    """
-#    )
-
     schema = {
         'type': 'object',
         'additionalProperties': {
@@ -45,16 +37,17 @@ class UrlRewrite(object):
     }
 
     def on_task_start(self, task, config):
+        resolves = self.resolves[task.name] = {}
         for name, rewrite_config in config.iteritems():
             match = re.compile(rewrite_config['regexp'])
             format = rewrite_config['format']
-            self.resolves[name] = {'regexp_compiled': match, 'format': format, 'regexp': rewrite_config['regexp']}
+            resolves[name] = {'regexp_compiled': match, 'format': format, 'regexp': rewrite_config['regexp']}
             log.debug('Added rewrite %s' % name)
 
     def url_rewritable(self, task, entry):
         log.trace('running url_rewritable')
         log.trace(self.resolves)
-        for name, config in self.resolves.iteritems():
+        for name, config in self.resolves.get(task.name, {}).iteritems():
             regexp = config['regexp_compiled']
             log.trace('testing %s' % config['regexp'])
             if regexp.search(entry['url']):
@@ -62,7 +55,7 @@ class UrlRewrite(object):
         return False
 
     def url_rewrite(self, task, entry):
-        for name, config in self.resolves.iteritems():
+        for name, config in self.resolves.get(task.name, {}).iteritems():
             regexp = config['regexp_compiled']
             format = config['format']
             if regexp.search(entry['url']):
@@ -73,8 +66,6 @@ class UrlRewrite(object):
 
                 if regexp.match(entry['url']):
                     entry.fail('urlrewriting')
-                    task.purge()
-                    from flexget.plugins.plugin_urlrewriting import UrlRewritingError
                     raise UrlRewritingError('Regexp %s result should NOT continue to match!' % name)
                 return
 
